Tlačítko vložit obrázek

Tlačítko vložit obrázek | Obsah

Tlačítko vložit obrázek otevře následující okno.
Jen vložte URL obrázku, který chcete přidat a zadáte jeho popis, jenž bude zobrazován jako alternativní popisek obrázku.
Popis políček:

URL obrázku | URL/cesta k obrázku.
Popis obrázku | Alternativní popis toho, co je na obrázku.
Rozměry | Šířka/výška obrázku.
Zarovnání | Zarovnání obrázku, vhodné pro obtékání obrázku textem.
Rámeček | Tloušťka rámečku.
Vertikální okraj | Vertikální okraj, vhodné pro zalomení textu kolem obrázku.
Horizontální okraj | Horizontální okraj, vhodné pro zalomení textu kolem obrázku.

Jdi na: Obsah | Nahoru